DROP VIEW IF EXISTS attribute_locale_v;
DROP VIEW IF EXISTS bulk_data_v;

CREATE VIEW attribute_locale_v AS 
 SELECT attr.attribute_key,
    attr.attribute_type,
    attr.entity_type,
    map.label_map AS localized_key,
    map.label_map_key AS locale
   FROM attribute_definition attr
     LEFT JOIN localized_label_map map ON attr.localized_display_name = map.localized_label
  WHERE (attr.entity_type::text = ANY (ARRAY['USER'::character varying, 'PERMISSION'::character varying, 'ACCOUNT'::character varying, 'GROUP'::character varying]::text[])) AND attr.attribute_type::text <> 'INTERNAL'::text AND attr.attribute_state::text = 'ACTIVE'::text
  ORDER BY attr.attribute_key;

CREATE VIEW bulk_data_v AS 
 SELECT ds.name AS source_name,
    dp.id,
    dp.data_producer_type,
    dp.end_time,
    dp.message,
    dp.start_time,
    dp.status,
    afeed.id AS advisor_feed,
    afeed.source_type,
    afeed.entity_type,
    afeed.name,
    afeed.description,
    afeed.configuration
   FROM data_production dp
     JOIN advisor_feed_curation afc ON afc.id = dp.id
     JOIN advisor_feed afeed ON afc.advisor_feed = afeed.id
     LEFT JOIN data_source ds ON ds.id = afeed.application
UNION
 SELECT ds.name AS source_name,
    dp.id,
    dp.data_producer_type,
    dp.end_time,
    dp.message,
    dp.start_time,
    dp.status,
    afeed.id AS advisor_feed,
    afeed.source_type,
    afeed.entity_type,
    afeed.name,
    afeed.description,
    afeed.configuration
   FROM data_production dp
     JOIN advisor_feed_generation afg ON afg.id = dp.id
     JOIN advisor_feed afeed ON afg.advisor_feed = afeed.id
     LEFT JOIN data_source ds ON ds.id = afeed.application;

ALTER TABLE attribute_locale_v
  OWNER TO igops;
GRANT ALL ON TABLE attribute_locale_v TO igops;
GRANT SELECT ON TABLE attribute_locale_v TO ig_report_role;

ALTER TABLE bulk_data_v
  OWNER TO igops;
GRANT ALL ON TABLE bulk_data_v TO igops;
GRANT SELECT ON TABLE bulk_data_v TO ig_report_role;